#
# spec file for package autotrash
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pythons python3

Name:           autotrash
Version:        0.4.7
Release:        1.1
Summary:        Tool to automatically purge old trashed files
License:        GPL-3.0-or-later
URL:            https://github.com/bneijt/autotrash
Source:         https://files.pythonhosted.org/packages/source/a/autotrash/%{name}-%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python3-pip
BuildRequires:  python3-poetry-core
BuildArch:      noarch

%description
Autotrash is a small python script to automatically remove (permanently delete)
trashed files. It relies on the FreeDesktop.org Trash files for it's deletion
information.

%prep
%autosetup
## Cleanup source for env and permissions
sed -i '/^#!/s/env \(.*\)$/\1/' src/autotrash/app.py
chmod 0755 src/autotrash/app.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%files
%license LICENSE.txt
%doc README.md
%{_bindir}/autotrash
%{python_sitelib}/autotrash
%{python_sitelib}/autotrash-%{version}.dist-info

%changelog
* Sat May  3 2025 Andrea Manzini <andrea.manzini@suse.com>
- Updated to version 0.4.7:
  * Read XDG_CONFIG_HOME environment variable instead of assuming ~/.config
  * Dependency upgrades
* Sat Mar  9 2024 malcolmlewis@opensuse.org
- Updated to version 0.4.6:
  + Upgrade dependencies, (gh#bneijt/autotrash#59).
  + Bump cryptography from 40.0.1 to 41.0.3,
    (gh#bneijt/autotrash#62).
  + Upgrade poetry, (gh#bneijt/autotrash#63).
  + OSV scan, (gh#bneijt/autotrash#54).
- Changes from version 0.4.5:
  + Add mypy and actions cache, (gh#bneijt/autotrash#42).
  + Update documentation, (gh#bneijt/autotrash#45).
  + Add .gnomerc Example For Granular Cleanup,
    (gh#bneijt/autotrash#46).
  + Upgrades, (gh#bneijt/autotrash#53).
- Update source URL.
- Update spec file, move to building with poetry macros.
* Wed Dec 29 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.4.4:
  + Tiny bit of love: change default template for systemd unit
    files to also contain a link to the project on github.
- Changes from version 0.4.3:
  + This release only fixes the license rendering on pypi.
- Changes from version 0.4.2:
  + Drop arrow dependency.
- Changes from version 0.4.1:
  + Release 0.4.1 but now with a package description in PyPi.
- Changes from version 0.4.0;
  + New --install feature to add systemctl timer.
- Changes from version 0.3.0:
  + A date parsing issue (#15) inspired me to revamp the
    distribution and packaging.
  + The package is no longer a single python script, but a full
    python package you will be able to install from PyPi shortly.
- Changes from version 0.2.1:
  + Prevent UnboundLocalError when --max-free is set and enough
    space free.
- Drop injected man page: upstream no longer maintains it
  apparently.
- Add python3-setuptools BuildRequires: new build dependency.
* Tue May 11 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Do not BuildRequire pandoc (as it does not exist on all
  architectures).
- Inject autotrash.1: build will fail when this needs to be
  regenerated (as pandoc would be missing).
* Sat Feb  6 2016 mailaender@opensuse.org
- initial packaging
